==> downloads.html?file=gigkalender_v1.2.61_069.zip: gigkalender/filesharing/filesharing.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  // Dateien umbenennen
    if ( isset($_POST['gesendet']) )
    {
      $i = 1;
      $handle=opendir ($directory);
      while ($file = readdir ($handle))
      {
        if ($file != "." && $file != "..")
        {

          $AlterDateiName = $file;
          $NeuerDateiName = str_replace(" ", "_", $AlterDateiName );
          $NeuerDateiName = str_replace("&","",utf8_encode($NeuerDateiName));
          $NeuerDateiName = str_replace("ß","ss",$NeuerDateiName );
          $NeuerDateiName = str_replace("ä","ae",$NeuerDateiName );
          $NeuerDateiName = str_replace("ö","oe",$NeuerDateiName );
          $NeuerDateiName = str_replace("ü","ue",$NeuerDateiName );
          $NeuerDateiName = str_replace("/", "",$NeuerDateiName );
          $NeuerDateiName = str_replace(":", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("'", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("{", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("}", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("(", "",$NeuerDateiName );
          $NeuerDateiName = str_replace(")", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("&", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("+", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("=", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("[", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("]", "",$NeuerDateiName );
          $NeuerDateiName = strtolower( $NeuerDateiName );
          while ( file_exists ( $directory. $NeuerDateiName ) )
          {
            $FileType = strrchr ( $NeuerDateiName, '.' );
            $NeuerDateiName = str_replace( $FileType, "",$NeuerDateiName );
            $NeuerDateiName = $NeuerDateiName.'_'.$i++;
            $NeuerDateiName = $NeuerDateiName.$FileType;
          }
          if ( !rename( $directory.$AlterDateiName, $directory.$NeuerDateiName) )
          {
            echo '<span class="Fehlermeldung">'.$L_195.' '.$file.' ->'.$NeuerDateiName.'</span><br />';
          }
          $i=1;
        }
      }
      closedir($handle);
    }
    // Dateinamen in Array schreiben
    $handle=opendir ($directory);
    $files = array();
    while ($file = readdir ($handle))
    if ($file != "." && $file != "..") { $files[] = $file; }
    sort ( $files );
    //Dateien zählen
    $AnzahlDateien = count($files);
    // Falsche Zeichen in Dateinamen feststellen
    $AnzahlFehler = 0;
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      $AnzahlFehler = substr_count( utf8_encode($files[$i]), ' ' );
      if ( $AnzahlFehler>0 )
      {
        echo '<span class="Fehlermeldung">'.$L_196.' '.utf8_encode($files[$i]).'</span><br />';
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([A-Z])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="Fehlermeldung">'.$L_197.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([/:\'{}()&+=])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="Fehlermeldung">'.$L_198.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([äöüÄÖÜß])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="Fehlermeldung">'.$L_199.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    if ( $AnzahlFehler )
    {
      if (  IsUserAdmin())
      {
        echo '<form method="post" action="index.php?submenue=filesharing&amp;inhalt='.$CurrentPage.'">
                <fieldset>
                  <input type="hidden" name="gesendet" value="1" />
                  <input style="width:8em;" class="SmallButton" type="submit" value="'.$L_Rename.'" onclick="javascript:allAttributes()" />
                </fieldset>
              </form><br />';
      }
    }
    if ( count($files) == 0) { echo $L_036; }
    else
    {
      echo '<table summary="FileSharing">
              <tr>
                <th>'.$AnzahlDateien.' '.$L_034.'</th>
                <th>'.$L_035.'</th>
              </tr>';
      $handle=opendir ($directory);
      for ( $i=0; $i<$AnzahlDateien; $i++)
      {
        $filesize =filesize($directory.$files[$i]);
        $filesize = ceil($filesize/1024).' KB';
        
        if ($filesize >= 1024) {$filesize = round($filesize/1024,3).' MB';}
        echo '<tr>
                <td><a href="'.$directory.utf8_encode($files[$i]).'">'.utf8_encode($files[$i]).'</a></td>
                <td class="TabellenSpalte_Rechts" style="text-align:right">'.$filesize.'</td>
              </tr>';
      }
      closedir($handle);
      echo '</table>';
    }
?>

==> downloads.html?file=gigkalender_v1.2.64.zip: gigkalender/filesharing/filesharing.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  // Dateien umbenennen
    if ( isset($_POST['gesendet']) )
    {
      $i = 1;
      $handle=opendir ($directory);
      while ($file = readdir ($handle))
      {
        if ($file != "." && $file != "..")
        {

          $AlterDateiName = $file;
          $NeuerDateiName = str_replace(" ", "_", $AlterDateiName );
          $NeuerDateiName = str_replace("&","",utf8_encode($NeuerDateiName));
          $NeuerDateiName = str_replace("ß","ss",$NeuerDateiName );
          $NeuerDateiName = str_replace("ä","ae",$NeuerDateiName );
          $NeuerDateiName = str_replace("ö","oe",$NeuerDateiName );
          $NeuerDateiName = str_replace("ü","ue",$NeuerDateiName );
          $NeuerDateiName = str_replace("/", "",$NeuerDateiName );
          $NeuerDateiName = str_replace(":", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("'", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("{", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("}", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("(", "",$NeuerDateiName );
          $NeuerDateiName = str_replace(")", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("&", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("+", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("=", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("[", "",$NeuerDateiName );
          $NeuerDateiName = str_replace("]", "",$NeuerDateiName );
          $NeuerDateiName = strtolower( $NeuerDateiName );
          while ( file_exists ( $directory. $NeuerDateiName ) )
          {
            $FileType = strrchr ( $NeuerDateiName, '.' );
            $NeuerDateiName = str_replace( $FileType, "",$NeuerDateiName );
            $NeuerDateiName = $NeuerDateiName.'_'.$i++;
            $NeuerDateiName = $NeuerDateiName.$FileType;
          }
          if ( !rename( $directory.$AlterDateiName, $directory.$NeuerDateiName) )
          {
            echo '<span class="ErrorMessage">'.$L_195.' '.$file.' ->'.$NeuerDateiName.'</span><br />';
          }
          $i=1;
        }
      }
      closedir($handle);
    }
    // Dateinamen in Array schreiben
    $handle=opendir ($directory);
    $files = array();
    while ($file = readdir ($handle))
    if ($file != "." && $file != "..") { $files[] = $file; }
    sort ( $files );
    //Dateien zählen
    $AnzahlDateien = count($files);
    // Falsche Zeichen in Dateinamen feststellen
    $AnzahlFehler = 0;
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      $AnzahlFehler = substr_count( utf8_encode($files[$i]), ' ' );
      if ( $AnzahlFehler>0 )
      {
        echo '<span class="ErrorMessage">'.$L_196.' '.utf8_encode($files[$i]).'</span><br />';
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([A-Z])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="ErrorMessage">'.$L_197.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([/:\'{}()&+=])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="ErrorMessage">'.$L_198.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    for ( $i=0; $i<$AnzahlDateien; $i++)
    {
      if ( preg_match( '([äöüÄÖÜß])', utf8_encode($files[$i]) ) )
      {
        echo '<span class="ErrorMessage">'.$L_199.' '.utf8_encode($files[$i]).'</span><br />';
        $AnzahlFehler++;
        break;
      }
    }
    if ( $AnzahlFehler )
    {
      if (  IsUserAdmin())
      {
        echo '<form method="post" action="index.php?submenue=filesharing&amp;inhalt='.$CurrentPage.'" accept-charset="UTF-8">
                <fieldset>
                  <input type="hidden" name="gesendet" value="1" />
                  <input style="width:8em;" class="SmallButton" type="submit" value="'.$L_Rename.'" onclick="javascript:allAttributes()" />
                </fieldset>
              </form><br />';
      }
    }
    if ( count($files) == 0) { echo $L_036; }
    else
    {
      echo '<table summary="FileSharing">
              <tr>
                <th>'.$AnzahlDateien.' '.$L_034.'</th>
                <th>'.$L_035.'</th>
              </tr>';
      $handle=opendir ($directory);
      for ( $i=0; $i<$AnzahlDateien; $i++)
      {
        $filesize =filesize($directory.$files[$i]);
        $filesize = ceil($filesize/1024).' KB';
        
        if ($filesize >= 1024) {$filesize = round($filesize/1024,3).' MB';}
        echo '<tr>
                <td><a href="'.$directory.utf8_encode($files[$i]).'">'.utf8_encode($files[$i]).'</a></td>
                <td class="TabellenSpalte_Rechts" style="text-align:right">'.$filesize.'</td>
              </tr>';
      }
      closedir($handle);
      echo '</table>';
    }
?>
